#
#   5B - Image classes and utilities
#

from pygame.transform import rotate, flip
from albow.resource import get_image

class RotatableImage(object):
	#
	#  A collection of precalculated rotated and flipped versions
	#  of an image, with facilities for drawing a selected one based
	#  on an orientation code.
	#
	#  The orientation code is an integer in the range 0-7 made up
	#  of the following bits:
	#
	#    0x1  Rotate 90 degrees anticlockwise
	#    0x2  Flip along x axis
	#    0x4  Flip along y axis
	#
	#  ------
	#
	#  images   [Surface * 8]   indexed by orientation code
	
	def __init__(self, base_image, **kwds):
		if isinstance(base_image, str):
			base_image = get_image(base_image, **kwds)
		images = [None] * 8
		images[0] = base_image
		images[1] = rotate(base_image, 90)
		for i in xrange(2, 8, 2):
			for j in xrange(2):
				images[i+j] = flip(images[j], i & 2, i & 4)
		self.images = images
	
	def __getitem__(self, orientation):
		return self.images[orientation]
	
	def draw(self, surf, center, orientation):
		#  Draw the image centred at the given point with the given orientation.
		image = self.images[orientation]
		r = image.get_rect()
		r.center = center.coords
		surf.blit(image, r)

	def get_rect(self, orientation):
		r = self.images[orientation].get_rect()
		r.center = (0, 0)
		return r