#
#   555-BOOM! - Game-wide settings and command line options
#

import os, sys
from optparse import OptionParser
from pygame.locals import *

screen_size = (800, 600)
flags = 0 # HWSURFACE | DOUBLEBUF
#frame_time = 40
frame_time = 50

# The following paths are relative to the directory containing
# the Game directory or the .app bundle.
default_save_dir_name = "Saves"
default_custom_level_dir_name = "Mods"

# The following is relative to the resource directory.
default_std_level_dir_name = "levels"

#usage = "%prog [options] [saved_game | level_file]"
usage = "%prog [options] [level_file]"

options = None
macosx_bundle = False

def extract_macosx_finder_launch_args():
	#  When launched from the Finder under MacOSX, we get called with
	#  a command line argument of the form -psn_N_NNNNN. We set a flag
	#  to remember this and delete the argument from argv.
	args = sys.argv[1:]
	print args
	if args and args[0].startswith("-psn_"):
		global macosx_bundle
		macosx_bundle = True
		del sys.argv[1]

def get_command_line_options():
	global options
	extract_macosx_finder_launch_args()
	parser = OptionParser(usage = usage)
	def opt(long, dest, help, short = None, type = None):
		if type:
			action = 'store'
		else:
			action = 'store_true'
		parser.add_option(short, long, action = action, dest = dest, help = help,
			type = type)
	opt("--edit", 'edit', "Start in edit mode", "-e")
	opt("--edit-std", 'edit_std_levels', "Enable editing standard levels", "-E")
	options, args = parser.parse_args()
	if args:
		options.filename = args[0]
	else:
		options.filename = None

def get_program_dir():
	#  Find the directory containing the program and the default
	#  Save and Mods directories. For the MacOSX bundle version, this is
	#  the directory containing the .app bundle. For other versions,
	#  this is the directory containing the Game directory.
	d = os.path.dirname
	path = d(d(sys.path[0]))
	if macosx_bundle:
		path = d(path)
	print "settings: program dir = %r" % path
	return path

def get_default_save_dir():
	parent = get_program_dir()
	return os.path.join(parent, default_save_dir_name)

def get_default_editor_level_dir():
	parent = get_program_dir()
	return os.path.join(parent, default_custom_level_dir_name)

def get_default_playing_level_dir():
	#parent = get_program_dir()
	#return os.path.join(parent, default_std_level_dir_name)
	from albow.resource import resource_path
	return resource_path(default_std_level_dir_name)

def milliseconds_to_frames(ms):
	return ms // frame_time

def seconds_to_frames(sec):
	return sec * 1000 // frame_time

def frames_to_seconds(frm):
	return frm * frame_time // 1000
